# hrenpack
#### [README на русском](https://github.com/MagIlyas-DOMA/hrenpack/blob/main/README_RU.md)
#### A universal python library for most tasks.

## The library is divided into several packages:
`__init__` - basic functions and functions that cannot be assigned to any category  
`boolwork` - working with boolean values    
`classes` - classes  
`clipboard_work` - working with the clipboard  
`cmd` - working with OS tools  
`constants` - various useful constants
`date_and_time_work` - working with date and time values  
`decorators` - decorators  
`functionwork` - working with functions  
`gpswork` - working with GPS  
`hashwork` - working with hashing  
`encapsulation` - full encapsulation  
`kwargswork` - working with **kwargs  
`listwork` - working with lists, tuples and dictionaries  
`network` - working with the Internet  
`numwork` - working with numbers  
`print_color` - color console. May not work in all consoles  
`resolution` - screen resolution detection  
`slugwork` - working with slug, i.e. with strings that match the rules  
`strwork` - working with strings  
`taskmgr` - working with tasks  
`type_define` - determining whether the data belongs to a certain type or not  
`windows_registry` - working with the Windows registry  

### In addition to packages, hrenpack has several sublibraries:
`custom_methods` - additional methods for existing objects  
`filework` - working with files  
`framework` - additional functions for existing libraries and frameworks

### Resources:
The resource folder contains resource files for the correct operation of hrenpack

## Usage:
This library is distributed under the 3-clause BSD license

## Updates
#### 1.1.x
###### 1.1.0
1. Removed modules `dec_to_hex`, `dbwork`, `office` due to their instability
2. Removed dependencies `pyodbc`
3. Added dependencies `gps`, `bcrypt`
4. Removed some functions from module `__init__`  
Removed due to errors
###### 1.1.1
Version 1.1.0 bugs fixed

